Struct minicbor::encode::ArrayIter

source ·
pub struct ArrayIter<I>(_);
An encodable iterator writing its items as a CBOR array.

This type wraps any type implementing Iterator + Clone and encodes the items produced by the iterator as a CBOR array.

Implementations