pub struct ArrayIter<I>(_);
An encodable iterator writing its items as a CBOR array.
This type wraps any type implementing Iterator + Clone and encodes
the items produced by the iterator as a CBOR array.
Formats the value using the given formatter.
Read more
Encode a value of this type using the given
Encoder.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.